==> kAWTv0_3_0.zip: java/awt/Frame.java <==
/*
 * Frame.java Version 0.11 99/11/07
 *
 * 1999-11-07   Version number 0.11 released
 * 1999-10-22   Version number 0.1 released
 *
 * Copyright 1999 by Stefan Haustein & Michael Kroll
 * 
 * stefan.haustein@trantor.de
 * michael.kroll@trantor.de
 *
 * All rights reserved.
 *
 * NO WARRANTY
 *
 *  1. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO
 *  WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE
 *  LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 *  HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT
 *  WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT
 *  NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *  FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS TO THE
 *  QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
 *  PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY
 *  SERVICING, REPAIR OR CORRECTION.
 * 
 *  2. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN
 *  WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY
 *  MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE
 *  LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL,
 *  INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR
 *  INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
 *  DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU
 *  OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY
 *  OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN
 *  ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 *  END OF TERMS AND CONDITIONS */

package java.awt;

import java.awt.event.*;
import java.util.Vector;


public class Frame extends Window {

    String title;
    Vector windows = new Vector ();

    public Frame () {
	this (null);
	/*
	  x = 0; 0 by default!
	  y = 0;
	  title = null;
	*/
    }

    
    public Frame (String t) {
	super (null);
	owner = this;
	new SpotletWrapper (this);
	setTitle (t);
    }
    

    public Dimension getMinimumSize () {
	return new Dimension (160, 160);
    }


    public Window getTopWindow () {
	return (windows.size () == 0 ? this : (Window) windows.lastElement ());
    }

    
    /*
      public Dimension gePreferredSize () {
	return new Dimension (160, 160);
	}
    */
    
    public void setTitle (String title) {
	
	if ((title == null) != (this.title == null)) {
	    valid = false; 
      
	    if (title != null)
		insets = new Insets (16, 0, 0, 0);
	    else 
		insets = new Insets (0, 0, 0, 0);
	    
	    this.title = title;
	}
	else if (title != null && !title.equals (this.title)) {
	    this.title = title;
	    repaint ();
	}
    }
    

    public void paint (Graphics g) {
	if (title != null) {
	  
	  g.setFont (g.getFont ().deriveFont (Font.BOLD));
	  int w = g.getFontMetrics ().stringWidth (title);
	  
	  g.fillRoundRect (0, 0, w + 5, 14, 3, 3);
	  g.drawLine (0, 13, 160, 13);
	  g.drawLine (0, 14, 160, 14);

	  g.setColor (Color.white);
	  g.drawString (title, 3, 12);

	}	
    }

    /*
    void _repaintBG (int x, int y, int w, int h) {
	
	Vector save = windows;
	
	windows = new Vector ();

	repaint (x, y, w, h);

	for (int i = 0; i < save.size (); i++) {
	    Window win = (Window) save.elementAt (i);
	    windows.addElement (win);
	    
	    win.repaint ();
	}
    }
    */
}

==> kAWTv0_6_0.zip: java/awt/Frame.java <==
/*
 * Frame.java Version 0.11 99/11/07
 *
 * 1999-11-07   Version number 0.11 released
 * 1999-10-22   Version number 0.1 released
 *
 * Copyright 1999 by Stefan Haustein & Michael Kroll
 * 
 * stefan.haustein@trantor.de
 * michael.kroll@trantor.de
 *
 * All rights reserved.
 *
 * NO WARRANTY
 *
 *  1. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO
 *  WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE
 *  LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 *  HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT
 *  WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT
 *  NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *  FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS TO THE
 *  QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
 *  PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY
 *  SERVICING, REPAIR OR CORRECTION.
 * 
 *  2. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN
 *  WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY
 *  MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE
 *  LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL,
 *  INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR
 *  INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
 *  DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU
 *  OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY
 *  OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN
 *  ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 *  END OF TERMS AND CONDITIONS */

package java.awt;

import java.awt.event.*;
import java.util.Vector;


public class Frame extends Window {

    String title;
    Vector windows = new Vector ();

    public Frame () {
	this (null);
	/*
	  x = 0; 0 by default!
	  y = 0;
	  title = null;
	*/
    }

    
    public Frame (String t) {
	super (null);
	owner = this;
	if (SpotletWrapper.wrapper == null) {
	    SpotletWrapper.wrapper = new SpotletWrapper ();
	}
	setTitle (t);
    }
    

    public Dimension getMinimumSize () {
	return new Dimension (160, 160);
    }


    public Window getTopWindow () {
	return (windows.size () == 0 ? this : (Window) windows.lastElement ());
    }

    
    /*
      public Dimension gePreferredSize () {
	return new Dimension (160, 160);
	}
    */
    
    public void setTitle (String title) {
	
	if ((title == null) != (this.title == null)) {
	    valid = false; 
      
	    if (title != null)
		insets = new Insets (16, 0, 0, 0);
	    else 
		insets = new Insets (0, 0, 0, 0);
	    
	    this.title = title;
	}
	else if (title != null && !title.equals (this.title)) {
	    this.title = title;
	    repaint ();
	}
    }
    

    public void paint (Graphics g) {
	if (title != null) {
	  
	  g.setFont (g.getFont ().deriveFont (Font.BOLD));
	  int w = g.getFontMetrics ().stringWidth (title);
	  
	  g.fillRoundRect (0, 0, w + 5, 14, 3, 3);
	  g.drawLine (0, 13, 160, 13);
	  g.drawLine (0, 14, 160, 14);

	  g.setColor (Color.white);
	  g.drawString (title, 3, 12);

	}	
    }

    
    public void setVisible (boolean vis) {
	if (vis == visible) return;

	visible = vis;

	if (vis) {
	    SpotletWrapper.wrapper.frames.addElement (this);
	    repaint ();
	}
	else {
	    SpotletWrapper.wrapper.frames.removeElement (this);
	    Frame act = SpotletWrapper.wrapper.getActiveFrame ();
	    if (act != null) act.repaint ();
	}
    }


    /*
    void _repaintBG (int x, int y, int w, int h) {
	
	Vector save = windows;
	
	windows = new Vector ();

	repaint (x, y, w, h);

	for (int i = 0; i < save.size (); i++) {
	    Window win = (Window) save.elementAt (i);
	    windows.addElement (win);
	    
	    win.repaint ();
	}
    }
    */
}
